==> mingw-w64-starpu-1.3.7-3.src.tar.gz: starpu-1.3.7/doc/doxygen_dev/html_dev/search/variables_11.js <==
var searchData=
[
  ['ranks',['ranks',['../data__movements__interface_8h.html#ab0eb0f0651d2f854c33ea1e63c7f739d',1,'data_movements_interface']]],
  ['readonly',['readonly',['../coherency_8h.html#a173cc183d075d2db15f1548393966e0b',1,'_starpu_data_state']]],
  ['ready_5fcond',['ready_cond',['../group__workers.html#a44970a437215b6ed939f7a9022ef0ffc',1,'_starpu_worker::ready_cond()'],['../group__workers.html#af75aa09443335da75b939ccd6f566614',1,'_starpu_worker_set::ready_cond()']]],
  ['ready_5fflops',['ready_flops',['../struct__starpu__sched__ctx.html#a3e4ccf0c8074f10d5f588801bb9d9802',1,'_starpu_sched_ctx']]],
  ['ready_5ftasks_5fbarrier',['ready_tasks_barrier',['../struct__starpu__sched__ctx.html#ac2a9ac6e32eeec350cbd89e23bfad610',1,'_starpu_sched_ctx']]],
  ['reduction_5frefcnt',['reduction_refcnt',['../coherency_8h.html#aeea89f05bb71c0d4872b4b95c7461ac8',1,'_starpu_data_state']]],
  ['reduction_5freq_5flist',['reduction_req_list',['../coherency_8h.html#ae317fcc65b070f031c58202277994bc9',1,'_starpu_data_state']]],
  ['reduction_5ftask',['reduction_task',['../struct__starpu__job.html#a84698231177bdbeee0f5e8fd57c463eb',1,'_starpu_job']]],
  ['redux_5fcl',['redux_cl',['../coherency_8h.html#a17f0d6200897bff37a1cc9f06d4bda47',1,'_starpu_data_state']]],
  ['refcnt',['refcnt',['../coherency_8h.html#a836b282fe38da8578af6d0a1f76e8c4b',1,'_starpu_data_replicate::refcnt()'],['../coherency_8h.html#aeae74f1f52eb6c6bef0b76660fbda828',1,'_starpu_data_state::refcnt()']]],
  ['relaxed_5fcoherency',['relaxed_coherency',['../coherency_8h.html#a84ce60d6b9a3a4fe924ed7187d31aab4',1,'_starpu_data_replicate']]],
  ['remaining',['remaining',['../cg_8h.html#a29739cdf3dbaf76e389ec9a88bbb25df',1,'_starpu_cg']]],
  ['request_5ftype',['request_type',['../struct__starpu__mpi__req.html#a55164a49c2333bb5d85542dfe4986199',1,'_starpu_mpi_req']]],
  ['requested',['requested',['../coherency_8h.html#af1be8064793295892b21e591db60250e',1,'_starpu_data_replicate']]],
  ['reverse_5fphase',['reverse_phase',['../group__workers.html#a177495c5b27e7c3903d6ba511d5a1a67',1,'_starpu_worker']]],
  ['root_5fhandle',['root_handle',['../coherency_8h.html#ac139bd07c4173210e9effed7083b941d',1,'_starpu_data_state']]],
  ['run_5fby_5fstarpu',['run_by_starpu',['../group__workers.html#a981216c1aac19202e8c7a1e8fe03e5ee',1,'_starpu_worker']]],
  ['run_5fsched_5fvar',['run_sched_var',['../openmp__runtime__support_8h.html#a30a8846caf2f61fe5758546fbddcf2dc',1,'starpu_omp_data_environment_icvs']]],
  ['running',['running',['../group__workers.html#a23f3e840d271a47f320a54b88848e8c5',1,'_starpu_machine_config']]]
];

==> mingw-w64-starpu-1.3.8-4.src.tar.gz: starpu-1.3.8/doc/doxygen_dev/html_dev/search/variables_11.js <==
var searchData=
[
  ['ranks',['ranks',['../data__movements__interface_8h.html#ab0eb0f0651d2f854c33ea1e63c7f739d',1,'data_movements_interface']]],
  ['readonly',['readonly',['../coherency_8h.html#a173cc183d075d2db15f1548393966e0b',1,'_starpu_data_state']]],
  ['ready_5fcond',['ready_cond',['../group__workers.html#a44970a437215b6ed939f7a9022ef0ffc',1,'_starpu_worker::ready_cond()'],['../group__workers.html#af75aa09443335da75b939ccd6f566614',1,'_starpu_worker_set::ready_cond()']]],
  ['ready_5fflops',['ready_flops',['../struct__starpu__sched__ctx.html#a3e4ccf0c8074f10d5f588801bb9d9802',1,'_starpu_sched_ctx']]],
  ['ready_5ftasks_5fbarrier',['ready_tasks_barrier',['../struct__starpu__sched__ctx.html#ac2a9ac6e32eeec350cbd89e23bfad610',1,'_starpu_sched_ctx']]],
  ['reduction_5frefcnt',['reduction_refcnt',['../coherency_8h.html#aeea89f05bb71c0d4872b4b95c7461ac8',1,'_starpu_data_state']]],
  ['reduction_5freq_5flist',['reduction_req_list',['../coherency_8h.html#ae317fcc65b070f031c58202277994bc9',1,'_starpu_data_state']]],
  ['reduction_5ftask',['reduction_task',['../struct__starpu__job.html#a84698231177bdbeee0f5e8fd57c463eb',1,'_starpu_job']]],
  ['redux_5fcl',['redux_cl',['../coherency_8h.html#a17f0d6200897bff37a1cc9f06d4bda47',1,'_starpu_data_state']]],
  ['refcnt',['refcnt',['../coherency_8h.html#a836b282fe38da8578af6d0a1f76e8c4b',1,'_starpu_data_replicate::refcnt()'],['../coherency_8h.html#aeae74f1f52eb6c6bef0b76660fbda828',1,'_starpu_data_state::refcnt()']]],
  ['relaxed_5fcoherency',['relaxed_coherency',['../coherency_8h.html#a84ce60d6b9a3a4fe924ed7187d31aab4',1,'_starpu_data_replicate']]],
  ['remaining',['remaining',['../cg_8h.html#a29739cdf3dbaf76e389ec9a88bbb25df',1,'_starpu_cg']]],
  ['request',['request',['../coherency_8h.html#a39a28a4f3a1d4a30163e098308b44ec2',1,'_starpu_data_replicate']]],
  ['request_5ftype',['request_type',['../struct__starpu__mpi__req.html#a55164a49c2333bb5d85542dfe4986199',1,'_starpu_mpi_req']]],
  ['reverse_5fphase',['reverse_phase',['../group__workers.html#a177495c5b27e7c3903d6ba511d5a1a67',1,'_starpu_worker']]],
  ['root_5fhandle',['root_handle',['../coherency_8h.html#ac139bd07c4173210e9effed7083b941d',1,'_starpu_data_state']]],
  ['run_5fby_5fstarpu',['run_by_starpu',['../group__workers.html#a981216c1aac19202e8c7a1e8fe03e5ee',1,'_starpu_worker']]],
  ['run_5fsched_5fvar',['run_sched_var',['../openmp__runtime__support_8h.html#a30a8846caf2f61fe5758546fbddcf2dc',1,'starpu_omp_data_environment_icvs']]],
  ['running',['running',['../group__workers.html#a23f3e840d271a47f320a54b88848e8c5',1,'_starpu_machine_config']]]
];
